Emission models
===============

Functions that can be used to generate some parts of inventory data.

Heating Degree Days (HDD)
^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: emiproc.profiles.hdd
    :members:


Human Respiration 
^^^^^^^^^^^^^^^^^ 

.. automodule:: emiproc.human_respiration
    :members:


VPRM 
^^^^

.. automodule:: emiproc.profiles.vprm
    :members:
